---
title: Build and Include the Libraries
summary: Some remarks on including the UNICADO libraries.
authors:
    - Sebastian Oberschwendtner
date: 2023-09-12
---
## A word about including the libraries

Oh yes, the **UNICADO** [libraries](../documentation/libraries.md). 🙂
When you start developing and building the **UNICADO** modules you will quickly discover the importance of the libraries.
There are many ways how you can include libraries in C++ projects and all have their advantages and disadvantages.
In the **UNICADO** project, the most important decisions to make are:

- Whether to include the libraries as **static** (`*.a`) or **dynamic** (`*.dll` or `*.so`) libraries.
- Whether to include the libraries as **CMake** **targets** and always recompile the libraries when building the modules or to import the libraries as a **CMake** **package** somewhere from the hard drive. ( :fontawesome-solid-arrow-right: Look in [ Include Library Package ](#) to find out what this actually means.) 


>  Note that each decision is completely independent from the other decision.

Each of those decisions has a corresponding option when configuring **CMake**.
So you can decide for your situation what suits your workflow the best.
The default configuration when [Building with CMake](build/cpp.md) is:

- `BUILD_SHARED_LIBS=OFF` :fontawesome-solid-arrow-right: Build **static** libraries.
- `FIND_LIBRARIES_AS_PACKAGE=OFF` :fontawesome-solid-arrow-right: Include **targets** from the submodule and recompile libraries each time there are changes.

!!! note
    The default configuration is usually best suited for most situations.

## Changing to dynamic libraries
When you want to decrease the binary size of the executables or want to test changes in the libraries without having to recompile the executables, you can build the libraries as **dynamic** libraries by configuring **CMake** with:

```sh
cmake -B build -S . --preset <preset> -DBUILD_SHARED_LIBS=ON
```

This will build all libraries as **dynamic** libraries and link the executables against those libraries.
It does not matter where you set this option.
When you build the libraries on their own, the option does the same thing as when you build the complete project where the libraries are included as a submodule.

!!! warning
    This is **not** recommended unless you have a specific need for it.
    Do not forget to add the location of the **dynamic** libraries to your **PATH** afterwards. 😉 

## Changing to the library package

When you want to save some compilation time or do not want to copy the libraries everywhere, you can include them as a package by:

```sh
cmake -B build -S . --preset <preset> -DFIND_LIBRARIES_AS_PACKAGE=ON -DCMAKE_PREFIX_PATH=path-to-libs
```

!!! important
    When including the libraries as a package you ^^**HAVE**^^ to set `CMAKE_PREFIX_PATH` as described in [ Include Library Package ](#). You also have to make sure that the libraries this path is pointing to are compiled and exist!

With this mechanism you can have mutliple projects using the same libraries without having to copy and recompile them all the time. The added downside is that **CMake** can no longer handle the automatic compilation and you have to manually make sure that the libraries are ready to be used.